package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Nov 4, 2023
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Generate a certificate using a configuration file and a private key in PEM format.
Generate a private key in PEM-format.
type Certificate struct {
Serial *big.Int `yaml:"serial"`
ValidForYears int `yaml:"validForYears"`
Subject certSubject `yaml:"subject"`
DNSNames []string `yaml:"dnsNames"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.